@@ -363,16 +363,18 @@ class BalanceNonDeferral(Wizard):
     def get_move_line(self, account):
         pool = Pool()
         Line = pool.get('account.move.line')
-        if account.company.currency.is_zero(account.balance):
+        # Don't use account.balance because we need the non-commulated balance
+        balance = account.debit - account.credit
+        if account.company.currency.is_zero(balance):
             return
         line = Line()
         line.account = account
-        if account.balance >= 0:
-            line.credit = abs(account.balance)
+        if balance >= 0:
+            line.credit = abs(balance)
             line.debit = 0
         else:
             line.credit = 0
-            line.debit = abs(account.balance)
+            line.debit = abs(balance)
         return line
 
     def get_counterpart_line(self, amount):
