@@ -6,7 +6,7 @@ from trytond.pyson import Eval
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.const import OPERATORS
-from trytond.backend import TableHandler
+from trytond import backend
 
 __all__ = ['Period', 'ClosePeriod', 'ReOpenPeriod']
 
@@ -44,6 +44,7 @@ class Period(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
 
         super(Period, cls).__register__(module_name)
@@ -108,18 +109,17 @@ class Period(ModelSQL, ModelView):
         cursor = Transaction().cursor
         if self.type != 'standard':
             return True
-        cursor.execute('SELECT id '
-                'FROM "' + self._table + '" '
-                'WHERE ((start_date <= %s AND end_date >= %s) '
-                        'OR (start_date <= %s AND end_date >= %s) '
-                        'OR (start_date >= %s AND end_date <= %s)) '
-                    'AND fiscalyear = %s '
-                    'AND type = \'standard\' '
-                    'AND id != %s',
-                (self.start_date, self.start_date,
-                    self.end_date, self.end_date,
-                    self.start_date, self.end_date,
-                    self.fiscalyear.id, self.id))
+        table = self.__table__()
+        cursor.execute(*table.select(table.id,
+                where=(((table.start_date <= self.start_date)
+                        & (table.end_date >= self.start_date))
+                    | ((table.start_date <= self.end_date)
+                        & (table.end_date >= self.end_date))
+                    | ((table.start_date >= self.start_date)
+                        & (table.end_date <= self.end_date)))
+                & (table.fiscalyear == self.fiscalyear.id)
+                & (table.type == 'standard')
+                & (table.id != self.id)))
         period_id = cursor.fetchone()
         if period_id:
             overlapping_period = self.__class__(period_id[0])
@@ -146,7 +146,7 @@ class Period(ModelSQL, ModelView):
                     'second': periods[0].rec_name,
                     })
         if (self.post_move_sequence.company and
-            self.post_move_sequence.company != self.fiscalyear.company):
+                self.post_move_sequence.company != self.fiscalyear.company):
             self.raise_user_error('check_move_sequence_company', {
                     'sequence': self.post_move_sequence.rec_name,
                     'period': self.rec_name,
@@ -202,7 +202,7 @@ class Period(ModelSQL, ModelView):
 
     @classmethod
     def search(cls, args, offset=0, limit=None, order=None, count=False,
-            query_string=False):
+            query=False):
         args = args[:]
 
         def process_args(args):
@@ -225,7 +225,7 @@ class Period(ModelSQL, ModelView):
                 i += 1
         process_args(args)
         return super(Period, cls).search(args, offset=offset, limit=limit,
-            order=order, count=count, query_string=query_string)
+            order=order, count=count, query=query)
 
     @classmethod
     def create(cls, vlist):
@@ -243,31 +243,35 @@ class Period(ModelSQL, ModelView):
         return super(Period, cls).create(vlist)
 
     @classmethod
-    def write(cls, periods, vals):
+    def write(cls, *args):
         Move = Pool().get('account.move')
-        for key in vals.keys():
-            if key in ('start_date', 'end_date', 'fiscalyear'):
-                cls._check(periods)
-                break
-        if vals.get('state') == 'open':
-            for period in periods:
-                if period.fiscalyear.state == 'close':
-                    cls.raise_user_error('open_period_closed_fiscalyear', {
-                            'period': period.rec_name,
-                            'fiscalyear': period.fiscalyear.rec_name,
-                            })
-        if vals.get('post_move_sequence'):
-            for period in periods:
-                if period.post_move_sequence and \
-                        period.post_move_sequence.id != \
-                        vals['post_move_sequence']:
-                    if Move.search([
-                                ('period', '=', period.id),
-                                ('state', '=', 'posted'),
-                                ]):
-                        cls.raise_user_error('change_post_move_sequence',
-                            (period.rec_name,))
-        super(Period, cls).write(periods, vals)
+        actions = iter(args)
+        args = []
+        for periods, values in zip(actions, actions):
+            for key in values.keys():
+                if key in ('start_date', 'end_date', 'fiscalyear'):
+                    cls._check(periods)
+                    break
+            if values.get('state') == 'open':
+                for period in periods:
+                    if period.fiscalyear.state == 'close':
+                        cls.raise_user_error('open_period_closed_fiscalyear', {
+                                'period': period.rec_name,
+                                'fiscalyear': period.fiscalyear.rec_name,
+                                })
+            if values.get('post_move_sequence'):
+                for period in periods:
+                    if (period.post_move_sequence
+                            and period.post_move_sequence.id !=
+                            values['post_move_sequence']):
+                        if Move.search([
+                                    ('period', '=', period.id),
+                                    ('state', '=', 'posted'),
+                                    ]):
+                            cls.raise_user_error('change_post_move_sequence',
+                                (period.rec_name,))
+            args.extend((periods, values))
+        super(Period, cls).write(*args)
 
     @classmethod
     def delete(cls, periods):
@@ -308,6 +312,13 @@ class Period(ModelSQL, ModelView):
     def post_move_sequence_used(self):
         return self.post_move_sequence or self.fiscalyear.post_move_sequence
 
+    @classmethod
+    def search_rec_name(cls, name, clause):
+        return ['OR',
+            ('code',) + tuple(clause[1:]),
+            (cls._rec_name,) + tuple(clause[1:]),
+            ]
+
 
 class ClosePeriod(Wizard):
     'Close Period'
